==> fantacalciobazar_0.5.2.tar.gz: fantacalciobazar/stat_campionato.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################



$parla = "NO";
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");

$giornata_ultima = "00";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_controlla = "giornata$num1";
if (!@is_file("$percorso_cartella_dati/$giornata_controlla")) break;
else $giornata_ultima = $num1;
} # fine for $num1

# leggo e immagazzino nelle 2 variabili qui sotto i dati su gol e risultati di tutte le giornate
unset($gol);
unset($scontri_esistenti);
for($num1 = 1 ; $num1 <= $giornata_ultima ; $num1++) {
$num_giornata_scontri = $num1;
if (strlen($num1) == 1) $num_giornata_scontri = "0".$num1;
$giornata_scontri = "giornata$num_giornata_scontri";
$file_giornata = file("$percorso_cartella_dati/$giornata_scontri");
$num_linee_file_giornata = count($file_giornata);
for($num2 = 0 ; $num2 < $num_linee_file_giornata; $num2++) {
$linea = togli_acapo($file_giornata[$num2]);
if ($linea == "#@& fine scontri #@&") $leggendo_scontri = "NO";
if ($leggendo_scontri == "SI") {
unset($scontri);
$scontri = explode("##@@&&",$linea);
if (count($scontri) == 4) $scontri_esistenti[$num1] = "SI";
$gol[$num1][$scontri[0]] = $scontri[2];
$gol[$num1][$scontri[1]] = $scontri[3];
} # fine if ($leggendo_scontri == "SI")
if ($linea == "#@& scontri #@&") {
$leggendo_scontri = "SI";
} # fine if ($linea == "#@& scontri #@&")
} # fine for $num2
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$nome_posizione[$num1+1] = $giocatore;
$soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra[3] = togli_acapo($soprannome_squadra[3]);
if ($soprannome_squadra[3]) $nome_sqadra_memo[$giocatore] = $soprannome_squadra[3];
else $nome_sqadra_memo[$giocatore] = $giocatore;
next($pass);
} # fine for $num1

echo "<br><center>";
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
$tipo_campionato = $campionato[$key_campionato];
$g_inizio_camp = $giornate_campionato[0];
$g_fine_camp = $giornate_campionato[1];
if ($tipo_campionato != "S" and $tipo_campionato != "P" and $tipo_campionato != "V") $tipo_campionato = "N";
if ($tipo_campionato != "N") {
#echo "<b>Statistiche del campionato</b> dalla giornata <b>$g_inizio_camp</b> alla <b>$g_fine_camp</b>";
#if ($tipo_campionato == "V") echo ": classifica per somma voti.<br><br>";
#if ($tipo_campionato == "P") echo ": classifica a punti per posizione.<br><br>";

if ($tipo_campionato == "S") {
unset($somma_punti);
unset($somma_vinte);
unset($somma_nulle);
unset($somma_perse);
unset($somma_gol_fatti);
unset($somma_gol_subiti);

echo "<b>Statistiche del campionato</b> dalla giornata <b>$g_inizio_camp</b> alla <b>$g_fine_camp</b>: scontri diretti.<br><br>";
$attiva_scontri_diretti = "NO";
if ($num_giocatori == 4 or $num_giocatori == 6 or $num_giocatori == 8 or $num_giocatori == 10 or $num_giocatori == 12) {
$attiva_scontri_diretti = "SI";
} # fine if ($num_giocatori == 4 or...
else echo "ERRORE: il numero di partecipanti non  di 4,6,8,10 o 12.<br><br>";

if ($attiva_scontri_diretti == "SI") {
$file_scontri = file("$percorso_cartella_scontri/squadre$num_giocatori");
$num_linee_file_scontri = count($file_scontri);
$finito_scontri = "NO";
$conta_cicli_while = 0;
$num_giornata_campionato = $g_inizio_camp - 1;
$giornata_scritta = $g_inizio_camp - 1;
#echo "<table align=\"center\">";
$num_cella = 1;
while ($finito_scontri != "SI") {
$inizio_campionato = "";
$campionato_in_corso = "";
$inizio_giornata = "";
$giornata_in_corso = "";
for ($num2 = 0 ; $num2 < $num_linee_file_scontri; $num2++) {
$linea_file_scontri = togli_acapo($file_scontri[$num2]);
if ($campionato_in_corso == "SI") {
if ($linea_file_scontri == "</campionato>") break;

if ($linea_file_scontri == "</giornata>") {
$giornata_in_corso = "NO";
if ($giornata_scritta <= $g_fine_camp) {
#echo "</table></td>";
if ($num_cella == 3) {
#echo "</tr>";
$num_cella = 0;
} # fine if ($num_cella == 3)
$num_cella++;
} # fine if ($giornata_scritta < $g_fine_camp)
} # fine if ($linea_file_scontri == "</giornata>")

if ($giornata_in_corso == "SI") {
$partita = explode("-",$linea_file_scontri);
$squadra1 = $nome_posizione[$partita[0]];
$squadra2 = $nome_posizione[$partita[1]];
#echo "<tr><td>".$nome_sqadra_memo[$squadra1]."-".$nome_sqadra_memo[$squadra2]."</td><td>".$gol[$num_giornata_campionato][$squadra1]."-".$gol[$num_giornata_campionato][$squadra2]."</td></tr>";
if ($scontri_esistenti[$num_giornata_campionato] == "SI") {
$somma_gol_fatti[$squadra1] = $somma_gol_fatti[$squadra1] + $gol[$num_giornata_campionato][$squadra1];
$somma_gol_fatti[$squadra2] = $somma_gol_fatti[$squadra2] + $gol[$num_giornata_campionato][$squadra2];
$somma_gol_subiti[$squadra1] = $somma_gol_subiti[$squadra1] + $gol[$num_giornata_campionato][$squadra2];
$somma_gol_subiti[$squadra2] = $somma_gol_subiti[$squadra2] + $gol[$num_giornata_campionato][$squadra1];
if ($gol[$num_giornata_campionato][$squadra1] > $gol[$num_giornata_campionato][$squadra2]) {
$somma_vinte[$squadra1]++;
$somma_perse[$squadra2]++;
$somma_punti[$squadra1] = $somma_punti[$squadra1] + $punti_partita_vinta;
$somma_punti[$squadra2] = $somma_punti[$squadra2] + $punti_partita_persa;
} # fine if ($gol[$num_giornata_campionato][$squadra1] > $gol[$num_giornata_campionato][$squadra2])
if ($gol[$num_giornata_campionato][$squadra1] == $gol[$num_giornata_campionato][$squadra2]) {
$somma_nulle[$squadra1]++;
$somma_nulle[$squadra2]++;
$somma_punti[$squadra1] = $somma_punti[$squadra1] + $punti_partita_pareggiata;
$somma_punti[$squadra2] = $somma_punti[$squadra2] + $punti_partita_pareggiata;
} # fine if ($gol[$num_giornata_campionato][$squadra1] == $gol[$num_giornata_campionato][$squadra2])
if ($gol[$num_giornata_campionato][$squadra1] < $gol[$num_giornata_campionato][$squadra2]) {
$somma_vinte[$squadra2]++;
$somma_perse[$squadra1]++;
$somma_punti[$squadra2] = $somma_punti[$squadra2] + $punti_partita_vinta;
$somma_punti[$squadra1] = $somma_punti[$squadra1] + $punti_partita_persa;
} # fine if ($gol[$num_giornata_campionato][$squadra1] < $gol[$num_giornata_campionato][$squadra2])
} # fine if ($scontri_esistenti[$num_giornata_campionato] == "SI")
} # fine if ($giornata_in_corso == "SI")

if ($inizio_giornata == "SI") {
$inizio_giornata = "";
$giornata_scritta++;
$num_giornata_campionato++;
if ($linea_file_scontri > $ultima_giornata) $ultima_giornata = $linea_file_scontri;
if ($giornata_scritta <= $g_fine_camp) {
#if ($num_cella == 1) echo "<tr>";
$giornata_in_corso = "SI";
#echo "<td><table align=\"center\" border=\"1\"><tr><td align=\"center\" colspan=2>Giornata $num_giornata_campionato</td></tr>";
} # fine if ($giornata_scritta < $g_fine_camp)
} # fine if ($inizio_giornata == "SI")
if ($linea_file_scontri == "<giornata>") $inizio_giornata = "SI";

} # fine if ($campionato_in_corso == "SI")
if ($inizio_campionato == "SI") {
$inizio_campionato = "";
if  ($linea_file_scontri == $num_giocatori) $campionato_in_corso = "SI";
} # fine if ($inizio_campionato)
if ($linea_file_scontri == "<campionato>") $inizio_campionato = "SI";
} # fine for $num2

if ($giornata_scritta >= $g_fine_camp) $finito_scontri = "SI";
$conta_cicli_while++;
if ($conta_cicli_while >= 50) $finito_scontri = "SI";
} # fine while ($finito_scontri != "SI")
#if ($num_cella != 1) echo "<tr>";
#echo "</table><br>";

if (@is_array($somma_punti)) {
function norm_zero ($val) {
if (!$val) $val = 0;
return $val;
} # fine function norm_zero
echo "<table border=2 cellspacing=0 cellpadding=5>
<tr><td>&nbsp;</td><td align=\"center\">P.TI</td><td align=\"center\">&nbsp;V&nbsp;</td><td align=\"center\">&nbsp;N&nbsp;</td>
<td align=\"center\">&nbsp;P&nbsp;</td><td align=\"center\">G.F.</td><td align=\"center\">G.S.</td><td align=\"center\">D.R.</td></tr>";
arsort ($somma_punti);
reset ($somma_punti);
while (list($key, $val) = each($somma_punti)) {
echo "<tr><td align=\"center\">".$nome_sqadra_memo[$key]."</td>
<td align=\"center\">".norm_zero($somma_punti[$key])."</td>
<td align=\"center\">".norm_zero($somma_vinte[$key])."</td>
<td align=\"center\">".norm_zero($somma_nulle[$key])."</td>
<td align=\"center\">".norm_zero($somma_perse[$key])."</td>
<td align=\"center\">".norm_zero($somma_gol_fatti[$key])."</td>
<td align=\"center\">".norm_zero($somma_gol_subiti[$key])."</td>
<td align=\"center\">".norm_zero($somma_gol_fatti[$key] - $somma_gol_subiti[$key])."</td></tr>";
} # fine while (list($key, $val) = each($somma_punti))
echo "</table><br>";
} # fine if (@is_array($somma_punti))


} # fine if ($attiva_scontri_diretti == "SI")


} # fine if ($tipo_campionato == "S")
} # fine if ($tipo_campionato != "N")
next($campionato);
} # fine for $num1
echo "</center>";

echo "<center><form method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Torna indietro\">
</form></center>";



include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.3.tar.gz: fantacalciobazar/stat_campionato.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################



include('./include/funzioni.php');
$parla = "NO";
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");

$giornata_ultima = "00";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_controlla = "giornata$num1";
if (!@is_file("$percorso_cartella_dati/$giornata_controlla")) break;
else $giornata_ultima = $num1;
} # fine for $num1

# leggo e immagazzino nelle 2 variabili qui sotto i dati su gol e risultati di tutte le giornate
unset($gol);
unset($scontri_esistenti);
for($num1 = 1 ; $num1 <= $giornata_ultima ; $num1++) {
$num_giornata_scontri = $num1;
if (strlen($num1) == 1) $num_giornata_scontri = "0".$num1;
$giornata_scontri = "giornata$num_giornata_scontri";
$file_giornata = file("$percorso_cartella_dati/$giornata_scontri");
$num_linee_file_giornata = count($file_giornata);
for($num2 = 0 ; $num2 < $num_linee_file_giornata; $num2++) {
$linea = togli_acapo($file_giornata[$num2]);
if ($linea == "#@& fine scontri #@&") $leggendo_scontri = "NO";
if ($leggendo_scontri == "SI") {
unset($scontri);
$scontri = explode("##@@&&",$linea);
if (count($scontri) == 4) $scontri_esistenti[$num1] = "SI";
$gol[$num1][$scontri[0]] = $scontri[2];
$gol[$num1][$scontri[1]] = $scontri[3];
} # fine if ($leggendo_scontri == "SI")
if ($linea == "#@& scontri #@&") {
$leggendo_scontri = "SI";
} # fine if ($linea == "#@& scontri #@&")
} # fine for $num2
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$nome_posizione[$num1+1] = $giocatore;
$soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra[3] = togli_acapo($soprannome_squadra[3]);
if ($soprannome_squadra[3]) $nome_sqadra_memo[$giocatore] = $soprannome_squadra[3];
else $nome_sqadra_memo[$giocatore] = $giocatore;
next($pass);
} # fine for $num1

echo "<br><center>";
$num_campionati = count($campionato);
reset($campionato);
for($num1 = 0 ; $num1 < $num_campionati; $num1++) {
$key_campionato = key($campionato);
$giornate_campionato = explode("-",$key_campionato);
$tipo_campionato = $campionato[$key_campionato];
$g_inizio_camp = $giornate_campionato[0];
$g_fine_camp = $giornate_campionato[1];
if ($tipo_campionato != "S" and $tipo_campionato != "P" and $tipo_campionato != "V") $tipo_campionato = "N";
if ($tipo_campionato != "N") {
#echo "<b>Statistiche del campionato</b> dalla giornata <b>$g_inizio_camp</b> alla <b>$g_fine_camp</b>";
#if ($tipo_campionato == "V") echo ": classifica per somma voti.<br><br>";
#if ($tipo_campionato == "P") echo ": classifica a punti per posizione.<br><br>";

if ($tipo_campionato == "S") {
unset($somma_punti);
unset($somma_vinte);
unset($somma_nulle);
unset($somma_perse);
unset($somma_gol_fatti);
unset($somma_gol_subiti);

echo "<b>Statistiche del campionato</b> dalla giornata <b>$g_inizio_camp</b> alla <b>$g_fine_camp</b>: scontri diretti.<br><br>";
$attiva_scontri_diretti = "NO";
if ($num_giocatori == 4 or $num_giocatori == 6 or $num_giocatori == 8 or $num_giocatori == 10 or $num_giocatori == 12) {
$attiva_scontri_diretti = "SI";
} # fine if ($num_giocatori == 4 or...
else echo "ERRORE: il numero di partecipanti non è di 4,6,8,10 o 12.<br><br>";

if ($attiva_scontri_diretti == "SI") {
$file_scontri = file("$percorso_cartella_scontri/squadre$num_giocatori");
$num_linee_file_scontri = count($file_scontri);
$finito_scontri = "NO";
$conta_cicli_while = 0;
$num_giornata_campionato = $g_inizio_camp - 1;
$giornata_scritta = $g_inizio_camp - 1;
#echo "<table align=\"center\">";
$num_cella = 1;
while ($finito_scontri != "SI") {
$inizio_campionato = "";
$campionato_in_corso = "";
$inizio_giornata = "";
$giornata_in_corso = "";
for ($num2 = 0 ; $num2 < $num_linee_file_scontri; $num2++) {
$linea_file_scontri = togli_acapo($file_scontri[$num2]);
if ($campionato_in_corso == "SI") {
if ($linea_file_scontri == "</campionato>") break;

if ($linea_file_scontri == "</giornata>") {
$giornata_in_corso = "NO";
if ($giornata_scritta <= $g_fine_camp) {
#echo "</table></td>";
if ($num_cella == 3) {
#echo "</tr>";
$num_cella = 0;
} # fine if ($num_cella == 3)
$num_cella++;
} # fine if ($giornata_scritta < $g_fine_camp)
} # fine if ($linea_file_scontri == "</giornata>")

if ($giornata_in_corso == "SI") {
$partita = explode("-",$linea_file_scontri);
$squadra1 = $nome_posizione[$partita[0]];
$squadra2 = $nome_posizione[$partita[1]];
#echo "<tr><td>".$nome_sqadra_memo[$squadra1]."-".$nome_sqadra_memo[$squadra2]."</td><td>".$gol[$num_giornata_campionato][$squadra1]."-".$gol[$num_giornata_campionato][$squadra2]."</td></tr>";
if ($scontri_esistenti[$num_giornata_campionato] == "SI") {
$somma_gol_fatti[$squadra1] = $somma_gol_fatti[$squadra1] + $gol[$num_giornata_campionato][$squadra1];
$somma_gol_fatti[$squadra2] = $somma_gol_fatti[$squadra2] + $gol[$num_giornata_campionato][$squadra2];
$somma_gol_subiti[$squadra1] = $somma_gol_subiti[$squadra1] + $gol[$num_giornata_campionato][$squadra2];
$somma_gol_subiti[$squadra2] = $somma_gol_subiti[$squadra2] + $gol[$num_giornata_campionato][$squadra1];
if ($gol[$num_giornata_campionato][$squadra1] > $gol[$num_giornata_campionato][$squadra2]) {
$somma_vinte[$squadra1]++;
$somma_perse[$squadra2]++;
$somma_punti[$squadra1] = $somma_punti[$squadra1] + $punti_partita_vinta;
$somma_punti[$squadra2] = $somma_punti[$squadra2] + $punti_partita_persa;
} # fine if ($gol[$num_giornata_campionato][$squadra1] > $gol[$num_giornata_campionato][$squadra2])
if ($gol[$num_giornata_campionato][$squadra1] == $gol[$num_giornata_campionato][$squadra2]) {
$somma_nulle[$squadra1]++;
$somma_nulle[$squadra2]++;
$somma_punti[$squadra1] = $somma_punti[$squadra1] + $punti_partita_pareggiata;
$somma_punti[$squadra2] = $somma_punti[$squadra2] + $punti_partita_pareggiata;
} # fine if ($gol[$num_giornata_campionato][$squadra1] == $gol[$num_giornata_campionato][$squadra2])
if ($gol[$num_giornata_campionato][$squadra1] < $gol[$num_giornata_campionato][$squadra2]) {
$somma_vinte[$squadra2]++;
$somma_perse[$squadra1]++;
$somma_punti[$squadra2] = $somma_punti[$squadra2] + $punti_partita_vinta;
$somma_punti[$squadra1] = $somma_punti[$squadra1] + $punti_partita_persa;
} # fine if ($gol[$num_giornata_campionato][$squadra1] < $gol[$num_giornata_campionato][$squadra2])
} # fine if ($scontri_esistenti[$num_giornata_campionato] == "SI")
} # fine if ($giornata_in_corso == "SI")

if ($inizio_giornata == "SI") {
$inizio_giornata = "";
$giornata_scritta++;
$num_giornata_campionato++;
if ($linea_file_scontri > $ultima_giornata) $ultima_giornata = $linea_file_scontri;
if ($giornata_scritta <= $g_fine_camp) {
#if ($num_cella == 1) echo "<tr>";
$giornata_in_corso = "SI";
#echo "<td><table align=\"center\" border=\"1\"><tr><td align=\"center\" colspan=2>Giornata $num_giornata_campionato</td></tr>";
} # fine if ($giornata_scritta < $g_fine_camp)
} # fine if ($inizio_giornata == "SI")
if ($linea_file_scontri == "<giornata>") $inizio_giornata = "SI";

} # fine if ($campionato_in_corso == "SI")
if ($inizio_campionato == "SI") {
$inizio_campionato = "";
if  ($linea_file_scontri == $num_giocatori) $campionato_in_corso = "SI";
} # fine if ($inizio_campionato)
if ($linea_file_scontri == "<campionato>") $inizio_campionato = "SI";
} # fine for $num2

if ($giornata_scritta >= $g_fine_camp) $finito_scontri = "SI";
$conta_cicli_while++;
if ($conta_cicli_while >= 50) $finito_scontri = "SI";
} # fine while ($finito_scontri != "SI")
#if ($num_cella != 1) echo "<tr>";
#echo "</table><br>";

if (@is_array($somma_punti)) {
function norm_zero ($val) {
if (!$val) $val = 0;
return $val;
} # fine function norm_zero
echo "<table border=2 cellspacing=0 cellpadding=5>
<tr><td>&nbsp;</td><td align=\"center\">P.TI</td><td align=\"center\">&nbsp;V&nbsp;</td><td align=\"center\">&nbsp;N&nbsp;</td>
<td align=\"center\">&nbsp;P&nbsp;</td><td align=\"center\">G.F.</td><td align=\"center\">G.S.</td><td align=\"center\">D.R.</td></tr>";
arsort ($somma_punti);
reset ($somma_punti);
while (list($key, $val) = each($somma_punti)) {
echo "<tr><td align=\"center\">".$nome_sqadra_memo[$key]."</td>
<td align=\"center\">".norm_zero($somma_punti[$key])."</td>
<td align=\"center\">".norm_zero($somma_vinte[$key])."</td>
<td align=\"center\">".norm_zero($somma_nulle[$key])."</td>
<td align=\"center\">".norm_zero($somma_perse[$key])."</td>
<td align=\"center\">".norm_zero($somma_gol_fatti[$key])."</td>
<td align=\"center\">".norm_zero($somma_gol_subiti[$key])."</td>
<td align=\"center\">".norm_zero($somma_gol_fatti[$key] - $somma_gol_subiti[$key])."</td></tr>";
} # fine while (list($key, $val) = each($somma_punti))
echo "</table><br>";
} # fine if (@is_array($somma_punti))


} # fine if ($attiva_scontri_diretti == "SI")


} # fine if ($tipo_campionato == "S")
} # fine if ($tipo_campionato != "N")
next($campionato);
} # fine for $num1
echo "</center>";

echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Torna indietro\">
</form></center>";



include("$percorso_cartella_dati/foot.php");
?>
